.. image:: https://imgur.com/Q9Lv0xo.png
     :target: https://github.com/dokipen/tubing
======

.. image:: https://travis-ci.org/dokipen/tubing.svg?branch=master
    :target: https://travis-ci.org/dokipen/tubing/
.. image:: https://coveralls.io/repos/github/dokipen/tubing/badge.svg?branch=master
    :target: https://coveralls.io/github/dokipen/tubing?branch=master
.. image:: https://img.shields.io/pypi/v/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/
.. image:: https://img.shields.io/pypi/pyversions/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/
.. image:: https://img.shields.io/pypi/dd/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/
.. image:: https://img.shields.io/pypi/l/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/
.. image:: https://img.shields.io/pypi/wheel/tubing.svg
    :target: https://pypi.python.org/pypi/tubing/

Tubing is a Python I/O library.
